{
    "scan": {
        "analyzer-version-clippy": "1.93.0",
        "analyzer-version-cppcheck": "2.19.1",
        "analyzer-version-gcc": "16.0.1",
        "analyzer-version-gcc-analyzer": "16.0.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-28.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20260119.105402.g7a5be1b.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "python-ogr-0.60.0.post1.dev5+g737bea6-1.20260130101155899279.pr973.5.g737bea6",
        "store-results-to": "/tmp/tmpe5y9usq3/python-ogr-0.60.0.post1.dev5+g737bea6-1.20260130101155899279.pr973.5.g737bea6.tar.xz",
        "time-created": "2026-01-30 10:22:42",
        "time-finished": "2026-01-30 10:23:55",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'cppcheck,unicontrol,shellcheck,gcc,clippy' '-o' '/tmp/tmpe5y9usq3/python-ogr-0.60.0.post1.dev5+g737bea6-1.20260130101155899279.pr973.5.g737bea6.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmpe5y9usq3/python-ogr-0.60.0.post1.dev5+g737bea6-1.20260130101155899279.pr973.5.g737bea6.src.rpm'",
        "tool-version": "csmock-3.8.3.20260128.181932.g41af877-1.el9"
    },
    "defects": []
}
